package com.hc.tripbusiness.model.jwt;

import com.hc.tripbusiness.model.Users;
import com.hc.tripbusiness.model.login.AccessEntity;
import com.hc.tripbusiness.model.login.AuthEntity;
import com.hc.tripbusiness.model.login.TokenEntity;
import com.hc.tripcore.utils.redis.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.SerializationUtils;

import java.util.Objects;

@Slf4j
@Component
public class GenerateAuthToken {

    private final RedisUtil redisUtil;

    @Autowired
    public GenerateAuthToken(RedisUtil redisUtil) {
        this.redisUtil = redisUtil;
    }

    public AccessEntity generateToken(AuthEntity auth, Users user) {

        AccessEntity accessEntity = new AccessEntity();
        accessEntity.setAuth(auth);
        TokenEntity tokenEntity = new TokenEntity();
        // 默认超时 8 小时
        tokenEntity.setExpires(60 * 60 * 8);
        String token = JWTUtil.sign(auth.getUserName(), auth.getPassword());
        tokenEntity.setId(token);


        accessEntity.setToken(tokenEntity);
        String accessEntityStr = null;
        try {
            accessEntityStr = new String(Objects.requireNonNull(SerializationUtils.serialize(accessEntity)));
        } catch (Exception e) {
            log.warn("{}-{}用户登录出错", auth.getUserName(), auth.getPassword());
        }
        // 写入到 redis
        redisUtil.set(accessEntity.getToken().getId(),
                accessEntityStr,
                accessEntity.getToken().getExpires());

        if (user != null) {
            tokenEntity.setPermissionLevel(4);
            accessEntity.setUser(user);
        }

        log.info("用户登录成功 user={}", auth.getUserName());
        return accessEntity;
    }
}
