package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.NewsTag;
import com.hc.tripbusiness.mapper.NewsTagMapper;
import com.hc.tripbusiness.service.NewsTagService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 新闻标签表(NewsTag)表服务实现类
 *
 * @author java
 * @since 2021-04-30 14:03:24
 */

@Service("newsTagService")
public class NewsTagServiceImpl implements NewsTagService {

    private final NewsTagMapper newsTagMapper;

    public NewsTagServiceImpl(NewsTagMapper newsTagMapper) {
        this.newsTagMapper = newsTagMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param tagId 主键
     * @return 实例对象
     */
    @Override
    public NewsTag queryById(Integer tagId) {
        return this.newsTagMapper.selectByPrimaryKey(tagId);
    }

    /**
     * 新增数据
     *
     * @param newsTag 实例对象
     * @return 实例对象
     */
    @Override
    public NewsTag insert(NewsTag newsTag) {
        newsTag.setCreateTime(System.currentTimeMillis());
        this.newsTagMapper.insert(newsTag);
        return newsTag;
    }

    /**
     * 修改数据
     *
     * @param newsTag 实例对象
     * @return 实例对象
     */
    @Override
    public NewsTag update(NewsTag newsTag) {
        newsTag.setUpdateTime(System.currentTimeMillis());
        this.newsTagMapper.updateByPrimaryKeySelective(newsTag);
        return this.queryById(newsTag.getTagId());
    }

    /**
     * 通过主键删除数据
     *
     * @param tagId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer tagId) {
        return this.newsTagMapper.deleteByPrimaryKey(tagId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.newsTagMapper::selectAll);
    }
}
