package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.SceneryPicture;
import com.hc.tripbusiness.mapper.SceneryPictureMapper;
import com.hc.tripbusiness.service.SceneryPictureService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 景点图片表(SceneryPicture)表服务实现类
 *
 * @author java
 * @since 2021-04-27 15:26:10
 */

@Service("sceneryPictureService")
public class SceneryPictureServiceImpl implements SceneryPictureService {

    private final SceneryPictureMapper sceneryPictureMapper;

    public SceneryPictureServiceImpl(SceneryPictureMapper sceneryPictureMapper) {
        this.sceneryPictureMapper = sceneryPictureMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param sceneryPictureId 主键
     * @return 实例对象
     */
    @Override
    public SceneryPicture queryById(Integer sceneryPictureId) {
        return this.sceneryPictureMapper.selectByPrimaryKey(sceneryPictureId);
    }

    /**
     * 新增数据
     *
     * @param sceneryPicture 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryPicture insert(SceneryPicture sceneryPicture) {
        sceneryPicture.setCreateTime(System.currentTimeMillis());
        this.sceneryPictureMapper.insert(sceneryPicture);
        return sceneryPicture;
    }

    /**
     * 修改数据
     *
     * @param sceneryPicture 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryPicture update(SceneryPicture sceneryPicture) {
        sceneryPicture.setUpdateTime(System.currentTimeMillis());
        this.sceneryPictureMapper.updateByPrimaryKeySelective(sceneryPicture);
        return this.queryById(sceneryPicture.getSceneryPictureId());
    }

    /**
     * 通过主键删除数据
     *
     * @param sceneryPictureId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer sceneryPictureId) {
        return this.sceneryPictureMapper.deleteByPrimaryKey(sceneryPictureId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryPictureMapper::selectAll);
    }
}
