package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.Scenery;
import com.hc.tripbusiness.mapper.SceneryMapper;
import com.hc.tripbusiness.service.SceneryService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 景点表(Scenery)表服务实现类
 *
 * @author java
 * @since 2021-04-25 09:27:40
 */

@Service("sceneryService")
public class SceneryServiceImpl implements SceneryService {

    private final SceneryMapper sceneryMapper;

    public SceneryServiceImpl(SceneryMapper sceneryMapper) {
        this.sceneryMapper = sceneryMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param sceneryId 主键
     * @return 实例对象
     */
    @Override
    public Scenery queryById(Integer sceneryId) {
        return this.sceneryMapper.selectByPrimaryKey(sceneryId);
    }

    /**
     * 新增数据
     *
     * @param scenery 实例对象
     * @return 实例对象
     */
    @Override
    public Scenery insert(Scenery scenery) {
        scenery.setCreateTime(System.currentTimeMillis());
        this.sceneryMapper.insert(scenery);
        return scenery;
    }

    /**
     * 修改数据
     *
     * @param scenery 实例对象
     * @return 实例对象
     */
    @Override
    public Scenery update(Scenery scenery) {
        scenery.setUpdateTime(System.currentTimeMillis());
        this.sceneryMapper.updateByPrimaryKeySelective(scenery);
        return this.queryById(scenery.getSceneryId());
    }

    /**
     * 通过主键删除数据
     *
     * @param sceneryId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer sceneryId) {
        return this.sceneryMapper.deleteByPrimaryKey(sceneryId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryMapper::selectAll);
    }
}
