package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.SceneryTag;
import com.hc.tripbusiness.mapper.SceneryTagMapper;
import com.hc.tripbusiness.service.SceneryTagService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 景点标签(SceneryTag)表服务实现类
 *
 * @author java
 * @since 2021-04-27 15:26:11
 */

@Service("sceneryTagService")
public class SceneryTagServiceImpl implements SceneryTagService {

    private final SceneryTagMapper sceneryTagMapper;

    public SceneryTagServiceImpl(SceneryTagMapper sceneryTagMapper) {
        this.sceneryTagMapper = sceneryTagMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param sceneryTagId 主键
     * @return 实例对象
     */
    @Override
    public SceneryTag queryById(Integer sceneryTagId) {
        return this.sceneryTagMapper.selectByPrimaryKey(sceneryTagId);
    }

    /**
     * 新增数据
     *
     * @param sceneryTag 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTag insert(SceneryTag sceneryTag) {
        sceneryTag.setCreateTime(System.currentTimeMillis());
        this.sceneryTagMapper.insert(sceneryTag);
        return sceneryTag;
    }

    /**
     * 修改数据
     *
     * @param sceneryTag 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTag update(SceneryTag sceneryTag) {
        sceneryTag.setUpdateTime(System.currentTimeMillis());
        this.sceneryTagMapper.updateByPrimaryKeySelective(sceneryTag);
        return this.queryById(sceneryTag.getSceneryTagId());
    }

    /**
     * 通过主键删除数据
     *
     * @param sceneryTagId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer sceneryTagId) {
        return this.sceneryTagMapper.deleteByPrimaryKey(sceneryTagId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryTagMapper::selectAll);
    }
}
