package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.SceneryTickets;
import com.hc.tripbusiness.mapper.SceneryTicketsMapper;
import com.hc.tripbusiness.service.SceneryTicketsService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 景点门票表(SceneryTickets)表服务实现类
 *
 * @author java
 * @since 2021-04-25 09:34:29
 */

@Service("sceneryTicketsService")
public class SceneryTicketsServiceImpl implements SceneryTicketsService {

    private final SceneryTicketsMapper sceneryTicketsMapper;

    public SceneryTicketsServiceImpl(SceneryTicketsMapper sceneryTicketsMapper) {
        this.sceneryTicketsMapper = sceneryTicketsMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param sceneryTicketId 主键
     * @return 实例对象
     */
    @Override
    public SceneryTickets queryById(Integer sceneryTicketId) {
        return this.sceneryTicketsMapper.selectByPrimaryKey(sceneryTicketId);
    }

    /**
     * 新增数据
     *
     * @param sceneryTickets 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTickets insert(SceneryTickets sceneryTickets) {
        sceneryTickets.setCreateTime(System.currentTimeMillis());
        this.sceneryTicketsMapper.insert(sceneryTickets);
        return sceneryTickets;
    }

    /**
     * 修改数据
     *
     * @param sceneryTickets 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTickets update(SceneryTickets sceneryTickets) {
        sceneryTickets.setUpdateTime(System.currentTimeMillis());
        this.sceneryTicketsMapper.updateByPrimaryKeySelective(sceneryTickets);
        return this.queryById(sceneryTickets.getSceneryTicketId());
    }

    /**
     * 通过主键删除数据
     *
     * @param sceneryTicketId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer sceneryTicketId) {
        return this.sceneryTicketsMapper.deleteByPrimaryKey(sceneryTicketId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryTicketsMapper::selectAll);
    }
}
