package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.SceneryTicketsType;
import com.hc.tripbusiness.mapper.SceneryTicketsTypeMapper;
import com.hc.tripbusiness.service.SceneryTicketsTypeService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 门票类型表(SceneryTicketsType)表服务实现类
 *
 * @author java
 * @since 2021-04-25 09:39:56
 */

@Service("sceneryTicketsTypeService")
public class SceneryTicketsTypeServiceImpl implements SceneryTicketsTypeService {

    private final SceneryTicketsTypeMapper sceneryTicketsTypeMapper;

    public SceneryTicketsTypeServiceImpl(SceneryTicketsTypeMapper sceneryTicketsTypeMapper) {
        this.sceneryTicketsTypeMapper = sceneryTicketsTypeMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param ticketsTypeId 主键
     * @return 实例对象
     */
    @Override
    public SceneryTicketsType queryById(Integer ticketsTypeId) {
        return this.sceneryTicketsTypeMapper.selectByPrimaryKey(ticketsTypeId);
    }

    /**
     * 新增数据
     *
     * @param sceneryTicketsType 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTicketsType insert(SceneryTicketsType sceneryTicketsType) {
        sceneryTicketsType.setCreateTime(System.currentTimeMillis());
        this.sceneryTicketsTypeMapper.insert(sceneryTicketsType);
        return sceneryTicketsType;
    }

    /**
     * 修改数据
     *
     * @param sceneryTicketsType 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryTicketsType update(SceneryTicketsType sceneryTicketsType) {
        sceneryTicketsType.setUpdateTime(System.currentTimeMillis());
        this.sceneryTicketsTypeMapper.updateByPrimaryKeySelective(sceneryTicketsType);
        return this.queryById(sceneryTicketsType.getTicketsTypeId());
    }

    /**
     * 通过主键删除数据
     *
     * @param ticketsTypeId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer ticketsTypeId) {
        return this.sceneryTicketsTypeMapper.deleteByPrimaryKey(ticketsTypeId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryTicketsTypeMapper::selectAll);
    }
}
