package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.SceneryVideo;
import com.hc.tripbusiness.mapper.SceneryVideoMapper;
import com.hc.tripbusiness.service.SceneryVideoService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 景点视频表(SceneryVideo)表服务实现类
 *
 * @author java
 * @since 2021-04-27 15:26:48
 */

@Service("sceneryVideoService")
public class SceneryVideoServiceImpl implements SceneryVideoService {

    private final SceneryVideoMapper sceneryVideoMapper;

    public SceneryVideoServiceImpl(SceneryVideoMapper sceneryVideoMapper) {
        this.sceneryVideoMapper = sceneryVideoMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param sceneryVideoId 主键
     * @return 实例对象
     */
    @Override
    public SceneryVideo queryById(Integer sceneryVideoId) {
        return this.sceneryVideoMapper.selectByPrimaryKey(sceneryVideoId);
    }

    /**
     * 新增数据
     *
     * @param sceneryVideo 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryVideo insert(SceneryVideo sceneryVideo) {
        sceneryVideo.setCreateTime(System.currentTimeMillis());
        this.sceneryVideoMapper.insert(sceneryVideo);
        return sceneryVideo;
    }

    /**
     * 修改数据
     *
     * @param sceneryVideo 实例对象
     * @return 实例对象
     */
    @Override
    public SceneryVideo update(SceneryVideo sceneryVideo) {
        sceneryVideo.setUpdateTime(System.currentTimeMillis());
        this.sceneryVideoMapper.updateByPrimaryKeySelective(sceneryVideo);
        return this.queryById(sceneryVideo.getSceneryVideoId());
    }

    /**
     * 通过主键删除数据
     *
     * @param sceneryVideoId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer sceneryVideoId) {
        return this.sceneryVideoMapper.deleteByPrimaryKey(sceneryVideoId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.sceneryVideoMapper::selectAll);
    }
}
