package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.UserOrderDetail;
import com.hc.tripbusiness.mapper.UserOrderDetailMapper;
import com.hc.tripbusiness.service.UserOrderDetailService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单详情表(UserOrderDetail)表服务实现类
 *
 * @author java
 * @since 2021-04-30 17:01:28
 */

@Service("userOrderDetailService")
public class UserOrderDetailServiceImpl implements UserOrderDetailService {

    private final UserOrderDetailMapper userOrderDetailMapper;

    public UserOrderDetailServiceImpl(UserOrderDetailMapper userOrderDetailMapper) {
        this.userOrderDetailMapper = userOrderDetailMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param orderDetailId 主键
     * @return 实例对象
     */
    @Override
    public UserOrderDetail queryById(Integer orderDetailId) {
        return this.userOrderDetailMapper.selectByPrimaryKey(orderDetailId);
    }

    /**
     * 新增数据
     *
     * @param userOrderDetail 实例对象
     * @return 实例对象
     */
    @Override
    public UserOrderDetail insert(UserOrderDetail userOrderDetail) {
        userOrderDetail.setCreateTime(System.currentTimeMillis());
        this.userOrderDetailMapper.insert(userOrderDetail);
        return userOrderDetail;
    }

    /**
     * 修改数据
     *
     * @param userOrderDetail 实例对象
     * @return 实例对象
     */
    @Override
    public UserOrderDetail update(UserOrderDetail userOrderDetail) {
        userOrderDetail.setUpdateTime(System.currentTimeMillis());
        this.userOrderDetailMapper.updateByPrimaryKeySelective(userOrderDetail);
        return this.queryById(userOrderDetail.getOrderDetailId());
    }

    /**
     * 通过主键删除数据
     *
     * @param orderDetailId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer orderDetailId) {
        return this.userOrderDetailMapper.deleteByPrimaryKey(orderDetailId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.userOrderDetailMapper::selectAll);
    }
}
