package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.UserOrders;
import com.hc.tripbusiness.mapper.UserOrdersMapper;
import com.hc.tripbusiness.service.UserOrdersService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 订单表(UserOrders)表服务实现类
 *
 * @author java
 * @since 2021-04-30 17:01:29
 */

@Service("userOrdersService")
public class UserOrdersServiceImpl implements UserOrdersService {

    private final UserOrdersMapper userOrdersMapper;

    public UserOrdersServiceImpl(UserOrdersMapper userOrdersMapper) {
        this.userOrdersMapper = userOrdersMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param ordersId 主键
     * @return 实例对象
     */
    @Override
    public UserOrders queryById(Integer ordersId) {
        return this.userOrdersMapper.selectByPrimaryKey(ordersId);
    }

    /**
     * 新增数据
     *
     * @param userOrders 实例对象
     * @return 实例对象
     */
    @Override
    public UserOrders insert(UserOrders userOrders) {
        userOrders.setCreateTime(System.currentTimeMillis());
        this.userOrdersMapper.insert(userOrders);
        return userOrders;
    }

    /**
     * 修改数据
     *
     * @param userOrders 实例对象
     * @return 实例对象
     */
    @Override
    public UserOrders update(UserOrders userOrders) {
        userOrders.setUpdateTime(System.currentTimeMillis());
        this.userOrdersMapper.updateByPrimaryKeySelective(userOrders);
        return this.queryById(userOrders.getOrdersId());
    }

    /**
     * 通过主键删除数据
     *
     * @param ordersId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer ordersId) {
        return this.userOrdersMapper.deleteByPrimaryKey(ordersId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.userOrdersMapper::selectAll);
    }
}
