package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.UserShop;
import com.hc.tripbusiness.mapper.UserShopMapper;
import com.hc.tripbusiness.service.UserShopService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 购物车表(UserShop)表服务实现类
 *
 * @author java
 * @since 2021-04-30 17:01:30
 */

@Service("userShopService")
public class UserShopServiceImpl implements UserShopService {

    private final UserShopMapper userShopMapper;

    public UserShopServiceImpl(UserShopMapper userShopMapper) {
        this.userShopMapper = userShopMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param userShopId 主键
     * @return 实例对象
     */
    @Override
    public UserShop queryById(Integer userShopId) {
        return this.userShopMapper.selectByPrimaryKey(userShopId);
    }

    /**
     * 新增数据
     *
     * @param userShop 实例对象
     * @return 实例对象
     */
    @Override
    public UserShop insert(UserShop userShop) {
        userShop.setCreateTime(System.currentTimeMillis());
        this.userShopMapper.insert(userShop);
        return userShop;
    }

    /**
     * 修改数据
     *
     * @param userShop 实例对象
     * @return 实例对象
     */
    @Override
    public UserShop update(UserShop userShop) {
        userShop.setUpdateTime(System.currentTimeMillis());
        this.userShopMapper.updateByPrimaryKeySelective(userShop);
        return this.queryById(userShop.getUserShopId());
    }

    /**
     * 通过主键删除数据
     *
     * @param userShopId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer userShopId) {
        return this.userShopMapper.deleteByPrimaryKey(userShopId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.userShopMapper::selectAll);
    }
}
