package com.hc.tripbusiness.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.model.UserTickets;
import com.hc.tripbusiness.mapper.UserTicketsMapper;
import com.hc.tripbusiness.service.UserTicketsService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户门票(UserTickets)表服务实现类
 *
 * @author java
 * @since 2021-04-30 17:01:31
 */

@Service("userTicketsService")
public class UserTicketsServiceImpl implements UserTicketsService {

    private final UserTicketsMapper userTicketsMapper;

    public UserTicketsServiceImpl(UserTicketsMapper userTicketsMapper) {
        this.userTicketsMapper = userTicketsMapper;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param userTicketsId 主键
     * @return 实例对象
     */
    @Override
    public UserTickets queryById(Integer userTicketsId) {
        return this.userTicketsMapper.selectByPrimaryKey(userTicketsId);
    }

    /**
     * 新增数据
     *
     * @param userTickets 实例对象
     * @return 实例对象
     */
    @Override
    public UserTickets insert(UserTickets userTickets) {
        userTickets.setCreateTime(System.currentTimeMillis());
        this.userTicketsMapper.insert(userTickets);
        return userTickets;
    }

    /**
     * 修改数据
     *
     * @param userTickets 实例对象
     * @return 实例对象
     */
    @Override
    public UserTickets update(UserTickets userTickets) {
        userTickets.setUpdateTime(System.currentTimeMillis());
        this.userTicketsMapper.updateByPrimaryKeySelective(userTickets);
        return this.queryById(userTickets.getUserTicketsId());
    }

    /**
     * 通过主键删除数据
     *
     * @param userTicketsId 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer userTicketsId) {
        return this.userTicketsMapper.deleteByPrimaryKey(userTicketsId) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.userTicketsMapper::selectAll);
    }
}
