package com.hc.tripbusiness.service.impl;

import cn.binarywang.wx.miniapp.api.WxMaService;
import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hc.tripbusiness.mapper.UsersMapper;
import com.hc.tripbusiness.model.Users;
import com.hc.tripbusiness.model.jwt.GenerateAuthToken;
import com.hc.tripbusiness.model.login.AccessEntity;
import com.hc.tripbusiness.model.login.AuthEntity;
import com.hc.tripbusiness.service.UsersService;
import com.hc.tripcore.utils.enums.InfoEnum;
import com.hc.tripcore.utils.exception.ResponseException;
import com.hc.tripcore.utils.tool.JsonUtils;
import com.hc.tripcore.utils.wechat.WxMaConfiguration;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.exception.WxErrorException;
import org.apache.commons.lang3.RandomStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * (Users)表服务实现类
 *
 * @author java
 * @since 2021-04-25 17:45:11
 */

@Slf4j
@Service("usersService")
public class UsersServiceImpl implements UsersService {

    private final UsersMapper usersMapper;

    private final GenerateAuthToken generateAuthToken;

    public UsersServiceImpl(UsersMapper usersMapper, GenerateAuthToken generateAuthToken) {
        this.usersMapper = usersMapper;
        this.generateAuthToken = generateAuthToken;
    }

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public Users queryById(Long id) {
        return this.usersMapper.selectByPrimaryKey(id);
    }

    /**
     * 新增数据
     *
     * @param users 实例对象
     * @return 实例对象
     */
    @Override
    public Users insert(Users users) {
        this.usersMapper.insert(users);
        return users;
    }

    /**
     * 修改数据
     *
     * @param users 实例对象
     * @return 实例对象
     */
    @Override
    public Users update(Users users) {
        this.usersMapper.updateByPrimaryKeySelective(users);
        return this.queryById(users.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Long id) {
        return this.usersMapper.deleteByPrimaryKey(id) > 0;
    }

    /**
     * 分页查询多条数据
     *
     * @param page 页码
     * @param size 查询条数
     * @return 对象列表
     */
    @Override
    public PageInfo queryAllByLimit(int page, int size) {
        return PageHelper.startPage(page, size).doSelectPageInfo(this.usersMapper::selectAll);
    }

    @Override
    public String login(String appid, String code) {

        if (StringUtils.isBlank(code)) {
            return "empty jscode";
        }

        final WxMaService wxService = WxMaConfiguration.getMaService(appid);
        try {
            WxMaJscode2SessionResult session = wxService.getUserService().getSessionInfo(code);
            log.info(session.getSessionKey());
            log.info(session.getOpenid());

            //TODO 可以增加自己的逻辑，关联业务相关数据

            List<Users> users = usersMapper.selectUserByOpenId(session.getOpenid());
            if (CollectionUtils.isEmpty(users)) {
                Users user = new Users();
                user.setOpenid(session.getOpenid());
                usersMapper.insert(user);
            }

            return JsonUtils.toJson(session);
        } catch (WxErrorException e) {
            log.error(e.getMessage(), e);
            return e.toString();
        }
    }

    @Override
    public AccessEntity selectUserByOpenId(String openId) {

        List<Users> users = usersMapper.selectUserByOpenId(openId);
        if (CollectionUtils.isEmpty(users)) {
            throw new ResponseException(InfoEnum.LOGIN_USER_NAME_ERROR);
        }

        Users user = users.get(0);
        AuthEntity authEntity = new AuthEntity();
        authEntity.setUserName(openId);
        authEntity.setPassword(RandomStringUtils.randomAlphanumeric(10));
        authEntity.setLoginType(1);
        return generateAuthToken.generateToken(authEntity, user);
    }


}
