package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.Banner;
import com.hc.tripbusiness.service.BannerService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 广告表
 * (Banner)表控制层
 *
 * @author java
 * @since 2021-04-30 14:19:20
 */

@RestController
@RequestMapping("/api/banner")
public class BannerController {

    /**
     * 服务对象
     */
    private final BannerService bannerService;

    public BannerController(BannerService bannerService) {
        this.bannerService = bannerService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 Banner", response = Result.class)
    public Result selectBanner(@PathVariable("id") Integer id) {
        return Result.success(this.bannerService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 Banner", response = Result.class)
    public Result addBanner(@Valid @RequestBody Banner banner) {
        return Result.success(bannerService.insert(banner));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 Banner", response = Result.class)
    public Result updateBanner(@RequestBody Banner banner) {
        return Result.success(bannerService.update(banner));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 Banner", response = Result.class)
    public Result deleteBanner(@PathVariable("id") Integer id) {
        return Result.success(bannerService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 Banner列表(分页)", response = Result.class)
    public Result listBanner(@RequestParam(defaultValue = "0") Integer page,
                             @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(bannerService.queryAllByLimit(page, size));
    }


}
