package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.News;
import com.hc.tripbusiness.service.NewsService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 新闻表
 * (News)表控制层
 *
 * @author java
 * @since 2021-04-30 14:03:23
 */

@RestController
@RequestMapping("/api/news")
public class NewsController {

    /**
     * 服务对象
     */
    private final NewsService newsService;

    public NewsController(NewsService newsService) {
        this.newsService = newsService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 News", response = Result.class)
    public Result selectNews(@PathVariable("id") Integer id) {
        return Result.success(this.newsService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 News", response = Result.class)
    public Result addNews(@Valid @RequestBody News news) {
        return Result.success(newsService.insert(news));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 News", response = Result.class)
    public Result updateNews(@RequestBody News news) {
        return Result.success(newsService.update(news));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 News", response = Result.class)
    public Result deleteNews(@PathVariable("id") Integer id) {
        return Result.success(newsService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 News列表(分页)", response = Result.class)
    public Result listNews(@RequestParam(defaultValue = "0") Integer page,
                           @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(newsService.queryAllByLimit(page, size));
    }


}
