package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.Roles;
import com.hc.tripbusiness.service.RolesService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * (Roles)表控制层
 *
 * @author java
 * @since 2021-04-30 15:08:18
 */

@RestController
@RequestMapping("/api/roles")
public class RolesController {

    /**
     * 服务对象
     */
    private final RolesService rolesService;

    public RolesController(RolesService rolesService) {
        this.rolesService = rolesService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 Roles", response = Result.class)
    public Result selectRoles(@PathVariable("id") Integer id) {
        return Result.success(this.rolesService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 Roles", response = Result.class)
    public Result addRoles(@Valid @RequestBody Roles roles) {
        return Result.success(rolesService.insert(roles));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 Roles", response = Result.class)
    public Result updateRoles(@RequestBody Roles roles) {
        return Result.success(rolesService.update(roles));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 Roles", response = Result.class)
    public Result deleteRoles(@PathVariable("id") Integer id) {
        return Result.success(rolesService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 Roles列表(分页)", response = Result.class)
    public Result listRoles(@RequestParam(defaultValue = "0") Integer page,
                            @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(rolesService.queryAllByLimit(page, size));
    }


}
