package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.Scenery;
import com.hc.tripbusiness.service.SceneryService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 景点表(Scenery)表控制层
 *
 * @author java
 * @since 2021-04-25 09:27:40
 */

@RestController
@RequestMapping("/api/scenery")
public class SceneryController {

    /**
     * 服务对象
     */
    private final SceneryService sceneryService;

    public SceneryController(SceneryService sceneryService) {
        this.sceneryService = sceneryService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 Scenery", response = Result.class)
    public Result selectScenery(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 Scenery", response = Result.class)
    public Result addScenery(@Valid @RequestBody Scenery scenery) {
        return Result.success(sceneryService.insert(scenery));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 Scenery", response = Result.class)
    public Result updateScenery(@RequestBody Scenery scenery) {
        return Result.success(sceneryService.update(scenery));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 Scenery", response = Result.class)
    public Result deleteScenery(@PathVariable("id") Integer id) {
        return Result.success(sceneryService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 Scenery列表(分页)", response = Result.class)
    public Result listScenery(@RequestParam(defaultValue = "0") Integer page,
                              @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryService.queryAllByLimit(page, size));
    }


}
