package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.SceneryPicture;
import com.hc.tripbusiness.service.SceneryPictureService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 景点图片表(SceneryPicture)表控制层
 *
 * @author java
 * @since 2021-04-27 15:26:10
 */

@RestController
@RequestMapping("/api/sceneryPicture")
public class SceneryPictureController {

    /**
     * 服务对象
     */
    private final SceneryPictureService sceneryPictureService;

    public SceneryPictureController(SceneryPictureService sceneryPictureService) {
        this.sceneryPictureService = sceneryPictureService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 SceneryPicture", response = Result.class)
    public Result selectSceneryPicture(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryPictureService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 SceneryPicture", response = Result.class)
    public Result addSceneryPicture(@Valid @RequestBody SceneryPicture sceneryPicture) {
        return Result.success(sceneryPictureService.insert(sceneryPicture));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 SceneryPicture", response = Result.class)
    public Result updateSceneryPicture(@RequestBody SceneryPicture sceneryPicture) {
        return Result.success(sceneryPictureService.update(sceneryPicture));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 SceneryPicture", response = Result.class)
    public Result deleteSceneryPicture(@PathVariable("id") Integer id) {
        return Result.success(sceneryPictureService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 SceneryPicture列表(分页)", response = Result.class)
    public Result listSceneryPicture(@RequestParam(defaultValue = "0") Integer page,
                                     @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryPictureService.queryAllByLimit(page, size));
    }


}
