package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.SceneryTag;
import com.hc.tripbusiness.service.SceneryTagService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 景点标签(SceneryTag)表控制层
 *
 * @author java
 * @since 2021-04-27 15:26:11
 */

@RestController
@RequestMapping("/api/sceneryTag")
public class SceneryTagController {

    /**
     * 服务对象
     */
    private final SceneryTagService sceneryTagService;

    public SceneryTagController(SceneryTagService sceneryTagService) {
        this.sceneryTagService = sceneryTagService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 SceneryTag", response = Result.class)
    public Result selectSceneryTag(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryTagService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 SceneryTag", response = Result.class)
    public Result addSceneryTag(@Valid @RequestBody SceneryTag sceneryTag) {
        return Result.success(sceneryTagService.insert(sceneryTag));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 SceneryTag", response = Result.class)
    public Result updateSceneryTag(@RequestBody SceneryTag sceneryTag) {
        return Result.success(sceneryTagService.update(sceneryTag));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 SceneryTag", response = Result.class)
    public Result deleteSceneryTag(@PathVariable("id") Integer id) {
        return Result.success(sceneryTagService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 SceneryTag列表(分页)", response = Result.class)
    public Result listSceneryTag(@RequestParam(defaultValue = "0") Integer page,
                                 @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryTagService.queryAllByLimit(page, size));
    }


}
