package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.SceneryTickets;
import com.hc.tripbusiness.service.SceneryTicketsService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 景点门票表(SceneryTickets)表控制层
 *
 * @author java
 * @since 2021-04-25 09:34:29
 */

@RestController
@RequestMapping("/api/sceneryTickets")
public class SceneryTicketsController {

    /**
     * 服务对象
     */
    private final SceneryTicketsService sceneryTicketsService;

    public SceneryTicketsController(SceneryTicketsService sceneryTicketsService) {
        this.sceneryTicketsService = sceneryTicketsService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 SceneryTickets", response = Result.class)
    public Result selectSceneryTickets(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryTicketsService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 SceneryTickets", response = Result.class)
    public Result addSceneryTickets(@Valid @RequestBody SceneryTickets sceneryTickets) {
        return Result.success(sceneryTicketsService.insert(sceneryTickets));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 SceneryTickets", response = Result.class)
    public Result updateSceneryTickets(@RequestBody SceneryTickets sceneryTickets) {
        return Result.success(sceneryTicketsService.update(sceneryTickets));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 SceneryTickets", response = Result.class)
    public Result deleteSceneryTickets(@PathVariable("id") Integer id) {
        return Result.success(sceneryTicketsService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 SceneryTickets列表(分页)", response = Result.class)
    public Result listSceneryTickets(@RequestParam(defaultValue = "0") Integer page,
                                     @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryTicketsService.queryAllByLimit(page, size));
    }


}
