package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.SceneryTicketsType;
import com.hc.tripbusiness.service.SceneryTicketsTypeService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 门票类型表(SceneryTicketsType)表控制层
 *
 * @author java
 * @since 2021-04-25 09:39:57
 */

@RestController
@RequestMapping("/api/sceneryTicketsType")
public class SceneryTicketsTypeController {

    /**
     * 服务对象
     */
    private final SceneryTicketsTypeService sceneryTicketsTypeService;

    public SceneryTicketsTypeController(SceneryTicketsTypeService sceneryTicketsTypeService) {
        this.sceneryTicketsTypeService = sceneryTicketsTypeService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 SceneryTicketsType", response = Result.class)
    public Result selectSceneryTicketsType(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryTicketsTypeService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 SceneryTicketsType", response = Result.class)
    public Result addSceneryTicketsType(@Valid @RequestBody SceneryTicketsType sceneryTicketsType) {
        return Result.success(sceneryTicketsTypeService.insert(sceneryTicketsType));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 SceneryTicketsType", response = Result.class)
    public Result updateSceneryTicketsType(@RequestBody SceneryTicketsType sceneryTicketsType) {
        return Result.success(sceneryTicketsTypeService.update(sceneryTicketsType));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 SceneryTicketsType", response = Result.class)
    public Result deleteSceneryTicketsType(@PathVariable("id") Integer id) {
        return Result.success(sceneryTicketsTypeService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 SceneryTicketsType列表(分页)", response = Result.class)
    public Result listSceneryTicketsType(@RequestParam(defaultValue = "0") Integer page,
                                         @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryTicketsTypeService.queryAllByLimit(page, size));
    }


}
