package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.SceneryVideo;
import com.hc.tripbusiness.service.SceneryVideoService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 景点视频表(SceneryVideo)表控制层
 *
 * @author java
 * @since 2021-04-27 15:26:48
 */

@RestController
@RequestMapping("/api/sceneryVideo")
public class SceneryVideoController {

    /**
     * 服务对象
     */
    private final SceneryVideoService sceneryVideoService;

    public SceneryVideoController(SceneryVideoService sceneryVideoService) {
        this.sceneryVideoService = sceneryVideoService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 SceneryVideo", response = Result.class)
    public Result selectSceneryVideo(@PathVariable("id") Integer id) {
        return Result.success(this.sceneryVideoService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 SceneryVideo", response = Result.class)
    public Result addSceneryVideo(@Valid @RequestBody SceneryVideo sceneryVideo) {
        return Result.success(sceneryVideoService.insert(sceneryVideo));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 SceneryVideo", response = Result.class)
    public Result updateSceneryVideo(@RequestBody SceneryVideo sceneryVideo) {
        return Result.success(sceneryVideoService.update(sceneryVideo));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 SceneryVideo", response = Result.class)
    public Result deleteSceneryVideo(@PathVariable("id") Integer id) {
        return Result.success(sceneryVideoService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 SceneryVideo列表(分页)", response = Result.class)
    public Result listSceneryVideo(@RequestParam(defaultValue = "0") Integer page,
                                   @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(sceneryVideoService.queryAllByLimit(page, size));
    }


}
