package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.UserOrderDetail;
import com.hc.tripbusiness.service.UserOrderDetailService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 订单详情表(UserOrderDetail)表控制层
 *
 * @author java
 * @since 2021-04-30 17:01:28
 */

@RestController
@RequestMapping("/api/userOrderDetail")
public class UserOrderDetailController {

    /**
     * 服务对象
     */
    private final UserOrderDetailService userOrderDetailService;

    public UserOrderDetailController(UserOrderDetailService userOrderDetailService) {
        this.userOrderDetailService = userOrderDetailService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 UserOrderDetail", response = Result.class)
    public Result selectUserOrderDetail(@PathVariable("id") Integer id) {
        return Result.success(this.userOrderDetailService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 UserOrderDetail", response = Result.class)
    public Result addUserOrderDetail(@Valid @RequestBody UserOrderDetail userOrderDetail) {
        return Result.success(userOrderDetailService.insert(userOrderDetail));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 UserOrderDetail", response = Result.class)
    public Result updateUserOrderDetail(@RequestBody UserOrderDetail userOrderDetail) {
        return Result.success(userOrderDetailService.update(userOrderDetail));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 UserOrderDetail", response = Result.class)
    public Result deleteUserOrderDetail(@PathVariable("id") Integer id) {
        return Result.success(userOrderDetailService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 UserOrderDetail列表(分页)", response = Result.class)
    public Result listUserOrderDetail(@RequestParam(defaultValue = "0") Integer page,
                                      @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(userOrderDetailService.queryAllByLimit(page, size));
    }


}
