package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.UserOrders;
import com.hc.tripbusiness.service.UserOrdersService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 订单表(UserOrders)表控制层
 *
 * @author java
 * @since 2021-04-30 17:01:29
 */

@RestController
@RequestMapping("/api/userOrders")
public class UserOrdersController {

    /**
     * 服务对象
     */
    private final UserOrdersService userOrdersService;

    public UserOrdersController(UserOrdersService userOrdersService) {
        this.userOrdersService = userOrdersService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 UserOrders", response = Result.class)
    public Result selectUserOrders(@PathVariable("id") Integer id) {
        return Result.success(this.userOrdersService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 UserOrders", response = Result.class)
    public Result addUserOrders(@Valid @RequestBody UserOrders userOrders) {
        return Result.success(userOrdersService.insert(userOrders));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 UserOrders", response = Result.class)
    public Result updateUserOrders(@RequestBody UserOrders userOrders) {
        return Result.success(userOrdersService.update(userOrders));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 UserOrders", response = Result.class)
    public Result deleteUserOrders(@PathVariable("id") Integer id) {
        return Result.success(userOrdersService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 UserOrders列表(分页)", response = Result.class)
    public Result listUserOrders(@RequestParam(defaultValue = "0") Integer page,
                                 @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(userOrdersService.queryAllByLimit(page, size));
    }


}
