package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.UserShop;
import com.hc.tripbusiness.service.UserShopService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 购物车表(UserShop)表控制层
 *
 * @author java
 * @since 2021-04-30 17:01:30
 */

@RestController
@RequestMapping("/api/userShop")
public class UserShopController {

    /**
     * 服务对象
     */
    private final UserShopService userShopService;

    public UserShopController(UserShopService userShopService) {
        this.userShopService = userShopService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 UserShop", response = Result.class)
    public Result selectUserOrders(@PathVariable("id") Integer id) {
        return Result.success(this.userShopService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 UserShop", response = Result.class)
    public Result addUserShop(@Valid @RequestBody UserShop userShop) {
        return Result.success(userShopService.insert(userShop));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 UserShop", response = Result.class)
    public Result updateUserShop(@RequestBody UserShop userShop) {
        return Result.success(userShopService.update(userShop));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 UserShop", response = Result.class)
    public Result deleteUserShop(@PathVariable("id") Integer id) {
        return Result.success(userShopService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 UserShop列表(分页)", response = Result.class)
    public Result listUserShop(@RequestParam(defaultValue = "0") Integer page,
                               @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(userShopService.queryAllByLimit(page, size));
    }


}
