package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.UserTickets;
import com.hc.tripbusiness.service.UserTicketsService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * 用户门票(UserTickets)表控制层
 *
 * @author java
 * @since 2021-04-30 17:01:31
 */

@RestController
@RequestMapping("/api/userTickets")
public class UserTicketsController {

    /**
     * 服务对象
     */
    private final UserTicketsService userTicketsService;

    public UserTicketsController(UserTicketsService userTicketsService) {
        this.userTicketsService = userTicketsService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 UserTickets", response = Result.class)
    public Result selectUserTickets(@PathVariable("id") Integer id) {
        return Result.success(this.userTicketsService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 UserTickets", response = Result.class)
    public Result addUserTickets(@Valid @RequestBody UserTickets userTickets) {
        return Result.success(userTicketsService.insert(userTickets));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 UserTickets", response = Result.class)
    public Result updateUserTickets(@RequestBody UserTickets userTickets) {
        return Result.success(userTicketsService.update(userTickets));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 UserTickets", response = Result.class)
    public Result deleteUserTickets(@PathVariable("id") Integer id) {
        return Result.success(userTicketsService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 UserTickets列表(分页)", response = Result.class)
    public Result listUserTickets(@RequestParam(defaultValue = "0") Integer page,
                                  @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(userTicketsService.queryAllByLimit(page, size));
    }


}
