package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.Users;
import com.hc.tripbusiness.service.UsersService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * (Users)表控制层
 *
 * @author java
 * @since 2021-04-25 17:45:11
 */

@RestController
@RequestMapping("/api/users")
public class UsersController {

    /**
     * 服务对象
     */
    private final UsersService usersService;

    public UsersController(UsersService usersService) {
        this.usersService = usersService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 Users", response = Result.class)
    public Result selectUsers(@PathVariable("id") Long id) {
        return Result.success(this.usersService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 Users", response = Result.class)
    public Result addUsers(@Valid @RequestBody Users users) {
        return Result.success(usersService.insert(users));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 Users", response = Result.class)
    public Result updateUsers(@RequestBody Users users) {
        return Result.success(usersService.update(users));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 Users", response = Result.class)
    public Result deleteUsers(@PathVariable("id") Long id) {
        return Result.success(usersService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 Users列表(分页)", response = Result.class)
    public Result listUsers(@RequestParam(defaultValue = "0") Integer page,
                            @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(usersService.queryAllByLimit(page, size));
    }


}
