package com.hc.tripweb.controller;

import com.hc.tripbusiness.model.UsersRole;
import com.hc.tripbusiness.service.UsersRoleService;
import com.hc.tripcore.utils.result.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;


/**
 * (UsersRole)表控制层
 *
 * @author java
 * @since 2021-04-30 15:08:37
 */

@RestController
@RequestMapping("/api/usersRole")
public class UsersRoleController {

    /**
     * 服务对象
     */
    private final UsersRoleService usersRoleService;

    public UsersRoleController(UsersRoleService usersRoleService) {
        this.usersRoleService = usersRoleService;
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "依据主键获取 UsersRole", response = Result.class)
    public Result selectUsersRole(@PathVariable("id") Integer id) {
        return Result.success(this.usersRoleService.queryById(id));
    }

    @PostMapping("/insert")
    @ApiOperation(value = "新增 UsersRole", response = Result.class)
    public Result addUsersRole(@Valid @RequestBody UsersRole usersRole) {
        return Result.success(usersRoleService.insert(usersRole));
    }

    @PutMapping("/update")
    @ApiOperation(value = "修改 UsersRole", response = Result.class)
    public Result updateUsersRole(@RequestBody UsersRole usersRole) {
        return Result.success(usersRoleService.update(usersRole));
    }

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "依据主键删除 UsersRole", response = Result.class)
    public Result deleteUsersRole(@PathVariable("id") Integer id) {
        return Result.success(usersRoleService.deleteById(id));
    }

    @GetMapping("/list")
    @ApiOperation(value = "获取 UsersRole列表(分页)", response = Result.class)
    public Result listUsersRole(@RequestParam(defaultValue = "0") Integer page,
                                @RequestParam(defaultValue = "0") Integer size) {
        return Result.success(usersRoleService.queryAllByLimit(page, size));
    }


}
